#!/bin/sh

# Macros Define Section
SLEEP_INTERVAL=1
COMMON_PATH=$PWD
LIBRARY_PATH="$COMMON_PATH/libiptc/.libs"
IP_TAB_BIN="$COMMON_PATH/.libs"
XTABLE_LIB_DIR=/usr/local/libexec/xtables
export LD_LIBRARY_PATH=$LIBRARY_PATH:$IP_TAB_BIN:$LD_LIBRARY_PATH

WL1271_start_web_browsing(){
     /sbin/ifconfig tiwlan0 &> /dev/null
     if [ "$?" -ne 0 ]; then
         echo "Please start the WLAN and check tiwlan0 interface is up"
         exit
     fi
    
     echo -n "ETH0 IP ADDR: " 
     read ETH_IP_ADDR

     /sbin/ifconfig eth0 $ETH_IP_ADDR netmask 255.255.255.0 up &> /dev/null
     if [ "$?" -ne 0 ]; then
         echo "Invalid ETH0 IP address \"$ETH_IP_ADDR\""
     fi

     /sbin/udhcpc -itiwlan0
     if [ "$?" -ne 0 ]; then
         echo "Access point is not connected to external network"
         exit
     fi

     ls $XTABLE_LIB_DIR &> /dev/null
     if [ "$?" -ne 0 ]; then
         mkdir -p $XTABLE_LIB_DIR &> /dev/null
         if [ "$?" -ne 0 ]; then
             "Can not create \"$XTABLE_LIB_DIR\" directory"
             exit
         fi
     
         cp -r $COMMON_PATH/extensions/*.so $XTABLE_LIB_DIR/
         if [ "$?" -ne 0 ]; then
             echo "Can not copy library file to \"$XTABLE_LIB_DIR\""
         fi
     fi

     ls $IP_TAB_BIN/iptables &> /dev/null
     if [ "$?" -ne 0 ]; then
         echo "\"iptable\" binary is not available"
         exit
     fi 
   
     cd $IP_TAB_BIN 
     ./iptables --flush
      if [ "$?" -ne 0 ]; then
          echo "IP routing failed ..."
          exit
      fi

     ./iptables --table nat --flush
     if [ "$?" -ne 0 ]; then
          echo "IP routing failed ..."
          exit
     fi
    
     ./iptables --delete-chain
     if [ "$?" -ne 0 ]; then
          echo "IP routing failed ..."
          exit
     fi
     ./iptables --table nat --delete-chain
     if [ "$?" -ne 0 ]; then
          echo "IP routing failed ..."
          exit
     fi
     ./iptables --table nat --append POSTROUTING --out-interface tiwlan0 -j MASQUERADE
     if [ "$?" -ne 0 ]; then
          echo "IP routing failed ..."
          exit
     fi
     ./iptables --append FORWARD --in-interface eth0 -j ACCEPT
     if [ "$?" -ne 0 ]; then
          echo "IP routing failed ..."
          exit
     fi
     echo 1 > /proc/sys/net/ipv4/ip_forward
}


case "$1" in
    start)
         echo "*************************************************************************"
         echo "*                    Web Browsing on local PC                           *"
         echo "*************************************************************************"
         WL1271_start_web_browsing
    ;; 
    --help)
        echo ""
        echo "This script helps to enable web browsing on local PC"
        echo "Web browsing Setup:"
        echo "      1. Connect the OMAP3 EVM and local PC using ethernet Cross Cable."
        echo "      2. Assign IP address to eth0 on OMAP3 EVM as xx.xx.xx.xx"
        echo "      3. Assign IP address to local PC as per the OMAP3 EVM eth0 network"
        echo "         and set the default getway as OMAP3 EVM eth0 IP on local PC"
        echo ""
        echo "Use below command to enable web browsing"
        echo "Usage:./WebBrowse.sh start"
        echo ""
    ;;   
    *)
        echo ""
        echo "Invalid command ..."
        echo "USE: --help to choose the option ..."
        echo ""
   ;;
esac
