#!/bin/bash

# Macros Define Section
SLEEP_INTERVAL=1
COMMON_PATH=$PWD
ROOT_PATH=$PWD/../../
KERNEL_PATH=$COMMON_PATH/kernel
BT_PATH=$COMMON_PATH/build/bluetooth
IMAGE_PATH=$COMMON_PATH/build/image
IMPORT_PATH=$COMMON_PATH
LOG_PATH=$COMMON_PATH/build/buildlog
BT_BUILD_PATH=$BT_PATH/WL1271_BT_PACKAGES
DEMO=$IMAGE_PATH/ti-bluetooth
HOST_INSTALL_PATH=$IMAGE_PATH/wl1271_bluetooth
TARGET_INSTALL_PATH=/opt/ti-bluetooth

INSTALL_PATH=$HOST_INSTALL_PATH$TARGET_INSTALL_PATH
SDK_INSTALL_PATH=$ROOT_PATH/linux-devkit/opt/arago-sdk/arm-none-linux-gnueabi/usr/

# Export Define Section
export TOOLCHAIN_PATH=/opt/codesourcery/2009q1-203
export PATH=$TOOLCHAIN_PATH/bin:$PATH
export DEMO_ROOT_DIR=$BT_PATH

export SDK_PATH=$ROOT_PATH/linux-devkit/opt/arago-sdk
export TARGET_SYS=arm-none-linux-gnueabi




# This function will extarct the module from the "commmon" folder and
# compile the packages for bluetooth module. The compiled binary will
# be install under "image/WiLink_Demo_Target" folder.
build_bt_module() {

    echo ""
    echo "Bluetooth module building ..."
    echo ""

#    mkdir -p $INSTALL_PATH

    export CC=$TOOLCHAIN_PATH/bin/arm-none-linux-gnueabi-gcc
    export CPP=$TOOLCHAIN_PATH/bin/arm-none-linux-gnueabi-cpp
    export AR=$TOOLCHAIN_PATH/bin/arm-none-linux-gnueabi-ar
    export STRIP=$TOOLCHAIN_PATH/bin/arm-none-linux-gnueabi-strip
    export RANLIB=$TOOLCHAIN_PATH/bin/arm-none-linux-gnueabi-ranlib
    export LD=$TOOLCHAIN_PATH/bin/arm-none-linux-gnueabi-ld
    export CROSS_COMPILE=arm-none-linux-gnueabi-

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES 2> /dev/null
    if [ "$?" -ne 0 ]; then
        mkdir -p $DEMO_ROOT_DIR/WL1271_BT_PACKAGES
    fi

    ls $LOG_PATH 2> /dev/null
    if [ "$?" -ne 0 ]; then
        mkdir -p $LOG_PATH
    fi
    cd $COMMON_PATH



}


# This function clean the bluetooth build.
clean_bt_module() {
    echo ""
    echo "Bluetooth Module Cleaning ..."
    echo ""
    ls $BT_BUILD_PATH &> /dev/null
    if [ "$?" -ne 0 ]; then
        echo "ERROR: Bluetooth Clean Failed ..."
        echo "There is no Buluetooth Module Availlable."
        return
    fi



    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/bluez-4.60 &> /dev/null
    if [ "$?" -ne 0 ]; then
       echo "ERROR: BLUEZ Clean Failed ..."
       echo "There is no GLIB Module Availlable."
       return
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/bluez-4.60/Makefile &> /dev/null
    if [ "$?" -eq 0 ]; then
        cd $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/bluez-4.60
        make distclean &> $LOG_PATH/btBuild.log
        if [ "$?" -ne 0 ]; then
            echo "ERROR: BLUEZ Clean Failed ..."
            return
        fi
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/openobex-1.5 &> /dev/null
    if [ "$?" -ne 0 ]; then
       echo "ERROR: OPENOBEX Clean Failed ..."
       echo "There is no GLIB Module Availlable."
       return
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/openobex-1.5/Makefile &> /dev/null
    if [ "$?" -eq 0 ]; then
        cd $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/openobex-1.5
        make distclean &> $LOG_PATH/btBuild.log
        if [ "$?" -ne 0 ]; then
            echo "ERROR: OPENOBEX Clean Failed ..."
            return
        fi
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/ussp-push-0.11 &> /dev/null
    if [ "$?" -ne 0 ]; then
       echo "ERROR: USSP Clean Failed ..."
       echo "There is no GLIB Module Availlable."
       return
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/ussp-push-0.11/Makefile &> /dev/null
    if [ "$?" -eq 0 ]; then
        cd $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/ussp-push-0.11
        make distclean &> $LOG_PATH/btBuild.log
        if [ "$?" -ne 0 ]; then
            echo "ERROR: USSP Clean Failed ..."
            return
        fi
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/obexftp-0.23 &> /dev/null
    if [ "$?" -ne 0 ]; then
       echo "ERROR: OBEXFTP Clean Failed ..."
       echo "There is no GLIB Module Availlable."
       return
    fi

    ls $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/obexftp-0.23/Makefile &> /dev/null
    if [ "$?" -eq 0 ]; then
        cd $DEMO_ROOT_DIR/WL1271_BT_PACKAGES/obexftp-0.23
        make distclean &> $LOG_PATH/btBuild.log
        if [ "$?" -ne 0 ]; then
            echo "ERROR: OBEXFTP Clean Failed ..."
            return
        fi
    fi


    echo "Bluetooth Module Cleaning Complete ..."
}

create_script_BT() {
    ls $DEMO &> /dev/null
    if [ "$?" -ne 0 ]; then
        mkdir  -p $DEMO
    fi

    ls $IMPORT_PATH/script/BTDemoScripts_01.tar &> /dev/null
    if [ "$?" -ne 0 ]; then
        echo "There is no BT script availble ..."
    else
        cp $IMPORT_PATH/script/BTDemoScripts_01.tar $DEMO/
        ls $DEMO/bluetooth_scripts &> /dev/null
        if [ "$?" -eq 0 ]; then
            rm -rf $DEMO/bluetooth_scripts
        fi
        cd $DEMO
        tar -xf BTDemoScripts_01.tar
        rm -rf $DEMO/BTDemoScripts_01.tar
    fi

    ls $IMPORT_PATH/gallery &> /dev/null
     if [ "$?" -ne 0 ]; then
        echo "There is no audio file under \"$IMPORT_PATH/audio_file\" ..."
        ls $DEMO/BT_FTP_storage &> /dev/null
        if [ "$?" -ne 0 ]; then
            mkdir -p $DEMO/BT_FTP_storage
        fi
    else
        ls $DEMO/BT_FTP_storage &> /dev/null
        if [ "$?" -ne 0 ]; then
            mkdir -p $DEMO/BT_FTP_storage
        fi

        ls $DEMO/BT_FTP_storage &> /dev/null
        if [ "$?" -eq 0 ]; then
            cp $IMPORT_PATH/gallery/*.jpg $DEMO/BT_FTP_storage/
        fi

        ls $DEMO/gallery &> /dev/null
        if [ "$?" -ne 0 ]; then
            mkdir -p $DEMO/gallery
            echo "Copy may take few minute, please wait ..."
            cp $IMPORT_PATH/gallery/*.* $DEMO/gallery/
        fi
    fi

    ls $IMPORT_PATH/BT_firmware &> /dev/null
    if [ "$?" -eq 0 ]; then
        cp -rf $IMPORT_PATH/BT_firmware $DEMO/firmware
    fi

    ls $DEMO/sbin &> /dev/null
    if [ "$?" -ne 0 ]; then
        mkdir -p $DEMO/sbin
    fi
    cp  $IMPORT_PATH/../binaries/wl1271bt_enable $DEMO/sbin/
}



wlan_bt_tar() {
    ls $IMAGE_PATH/ti-bluetooth.tar.bz2 &> /dev/null
    if [ "$?" -eq 0 ]; then
        rm -rf $IMAGE_PATH/ti-bluetooth.tar.bz2
    fi

    ls $DEMO &> /dev/null
    if [ "$?" -ne 0 ]; then
        echo "WLAN OR/AND Bluetooth binaries are not built"
    else
        echo "Creating tarball file, please wait ..."
        cd $DEMO/../
        tar -cjf ti-bluetooth.tar.bz2  ti-bluetooth/ &> /dev/null
        rm -rf ti-bluetooth/
    fi
}


# This case will take the parameter for build|rebuild|buildclean
# for the modules kernel|wlan|bluetooth|all. This script is required
# atleast 3 parameters for execution.
case "$1" in
    build)
    if [ $# -lt 1 ]; then
        echo ""
        echo "Follow the below help to build the modules .........."
        echo ""
        $0 --help
        exit
    fi

    echo "Building the modules ..."

     build_bt_module
     create_script_BT

    ls $IMPORT_PATH/script/install-bt.sh &> /dev/null
    if [ "$?" -ne 0 ]; then
        echo "Install script is not available ...."
        exit
    else
        ls $DEMO &> /dev/null
        if [ "$?" -eq 0 ]; then
           cp $IMPORT_PATH/script/install-bt.sh $DEMO/install.sh
           cp $IMPORT_PATH/script/Readme.txt $DEMO/
        fi
    fi

    # Create the tar file
    wlan_bt_tar

    echo "Build modules Completed..."
    echo ""
    echo "All compiled modules binary availble under \"$IMAGE_PATH\" folder"
    echo ""
    ;;
    buildclean)
    if [ $# -lt 1 ]; then
        echo ""
        echo "Follow the below help to build the modules .........."
        echo ""
        $0 --help
        exit
    fi

    echo ""
    echo "Cleaning the modules ..."
        clean_bt_module
    echo ""
    echo "Clean modules Completed..."
    echo ""
    ;;
    rebuild)
    if [ $# -lt 1 ]; then
        echo ""
        echo "Follow the below help to build the modules .........."
        echo ""
        $0 --help
        exit
    fi
    echo ""
    echo "Rebuilding the modules ..."
    echo ""
    $0 buildclean $2 $3
    sleep "$SLEEP_INTERVAL"
    $0 build $2 $3
    echo "Rebuild Completed ..."
    echo ""
    ;;
    --help)
    echo ""
    echo "Collect Information to building the modules"
    echo "Usage:./wl1271_bt_build.sh [OPTION] "
    echo ""
    echo "[OPTION]:"
    echo ""
    echo "       build       --Build modules"
    echo "       rebuild     --Rebuild modules"
    echo "       buildclean  --Clean the build modules"
    echo ""
    echo ""
    ;;
    *)
    echo ""
    echo "Invalid command ..."
    echo "USE: --help to choose the option ..."
    echo ""
    ;;
esac


