#!/bin/bash
#################################################
#           User Edit Section                   #
#################################################

# Set the tool chain path as per tool chain installed path
#TOOLCHAIN_PATH=/opt/codesourcery/2009q1-203
TOOLCHAIN_PATH=/opt/codesc/2009q1-203
# Set the kernel build path
KERNEL_DIR=/home/premi/sdk/AM35x-OMAP35x-PSP-SDK-03.00.00.05/src/kernel/linux-03.00.01.06


#################################################
#           Don't Edit Section                  #
#################################################
# Macros Define Section
SLEEP_INTERVAL=1
NO_MODULE=""
WLAN_MODULE="wlan"
COMMON_PATH=$PWD
IMPORT_PATH=$COMMON_PATH/wlan_application
CUDK_PATH=$COMMON_PATH/wlan_application_build/CUDK
BUILD_PATH=$COMMON_PATH/wlan_application_build

# Export Define Section
export PATH=$TOOLCHAIN_PATH/bin:$PATH


# This function build the wireless module. It can extract module from "common" folder
# and apply the patch; and compile the WLAN module. The compiled binary will be 
# available under the "image" folder 
build_wlan_module() {
    echo ""
    echo "Wireless module building ..."
  
    export CROSS_COMPILE=arm-none-linux-gnueabi-
    export ARCH=arm
    export HOST_PLATFORM=omap3530
    export XCC=n

    ls $CUDK_PATH &> /dev/null
    if [ "$?" -ne 0 ]; then
        mkdir -p $BUILD_PATH
        cd $BUILD_PATH
        tar -xzf $IMPORT_PATH/CUDK.tar.gz
    fi
    cd $CUDK_PATH
    make CROSS_COMPILE=arm-none-linux-gnueabi- KERNEL_DIR=$KERNEL_DIR
    if [ "$?" -ne 0 ]; then
       echo "WLAN Application build fail ........."
       exit
    fi
    ls $COMMON_PATH/build/image/ti-wireless &> /dev/null
    if [ "$?" -ne 0 ]; then
        mkdir -p $COMMON_PATH/build/image/ti-wireless
    fi
    
    cp $CUDK_PATH/output/tiwlan_loader $COMMON_PATH/build/image/ti-wireless/
    cp $CUDK_PATH/output/wlan_cu $COMMON_PATH/build/image/ti-wireless/
    cp $CUDK_PATH/output/wlan_logger $COMMON_PATH/build/image/ti-wireless/
    cp $CUDK_PATH/output/wpa_supplicant.txt $COMMON_PATH/build/image/ti-wireless/
    cp $CUDK_PATH/misc/firmware.bin  $COMMON_PATH/build/image/ti-wireless/
    cp $CUDK_PATH/misc/tiwlan.ini $COMMON_PATH/build/image/ti-wireless/

    ls $COMMON_PATH/script/install-wlan.sh &> /dev/null
    if [ "$?" -ne 0 ]; then
        echo "Install script is not available ...."
        exit
    else
        ls $COMMON_PATH/build/image/ti-wireless &> /dev/null
        if [ "$?" -eq 0 ]; then
           cp $COMMON_PATH/script/install-wlan.sh $COMMON_PATH/build/image/ti-wireless/install.sh
        fi
    fi

    cd $COMMON_PATH/build/image
    if [ "$?" -ne 0 ]; then
        echo "Can not create Wireless application tar ball"
        exit
    fi
    tar -cjf ti-wireless.tar.bz2 ti-wireless/
    ls ti-wireless.tar.bz2 &> /dev/null
    if [ "$?" -eq 0 ]; then
       rm -rf ti-wireless/
       echo "Wireless application package(ti-wireless.tar.bz2) available under \"$COMMON_PATH/build/image/\""
    fi

    echo ""
    echo "Wireless module build Completed ..."
    echo ""
}


# This function wiil clean the wireless module build
clean_wlan_module() {
    echo ""
    echo "Wireless module cleaning ..."

    ls  $CUDK_PATH &> /dev/null 
    if [ "$?" -ne 0 ]; then
        echo "ERROR: Wireless Clean Failed ..."
        echo "There is no Wireless Module Available."
        return
    fi

    cd $CUDK_PATH
    make CROSS_COMPILE=arm-none-linux-gnueabi- clean
    echo "Wireless Module Cleaning Completed ..."
}


# This case will take the parameter for build|rebuild|buildclean
# for the modules kernel|wlan|bluetooth|all. This script is required
# atleast 3 parameters for execution.
case "$1" in
    build)
    if [ $# -lt 1 ]; then
        echo ""
        echo "Follow the below help to build the modules .........."
        echo ""
        $0 --help
        exit
    fi

    echo "Building the modules ..."
        build_wlan_module

    echo "Build modules Completed..."
    ;;
    buildclean)
    if [ $# -lt 1 ]; then
        echo ""
        echo "Follow the below help to build the modules .........."
        echo ""
        $0 --help
        exit
    fi

    echo ""
    echo "Cleaning the modules ..."
        clean_wlan_module
    echo ""
    echo "Clean modules Completed..."
    echo ""
    ;;
    rebuild)
    if [ $# -lt 1 ]; then
        echo ""
        echo "Follow the below help to build the modules .........."
        echo ""
        $0 --help
        exit
    fi
    echo ""
    echo "Rebuilding the modules ..." 
    echo ""
    $0 buildclean $2 $3
    sleep "$SLEEP_INTERVAL"
    $0 build $2 $3
    echo "Rebuild Completed ..."
    echo ""
    ;;
    --help)
    echo ""
    echo "Collect Information to building the modules"
    echo "Usage:./wl1271_wlan_build.sh [OPTION]"
    echo ""
    echo "[OPTION]:"
    echo ""
    echo "       build       --Build modules"
    echo "       rebuild     --Rebuild modules"
    echo "       buildclean  --Clean the build modules"
    echo ""
    ;;
    *)
    echo ""
    echo "Invalid command ..."
    echo "USE: --help to choose the option ..."
    echo ""
    ;;
esac


